<?php

namespace Drupal\feature_toggle;

/**
 * Feature wrapper class.
 */
class Feature implements FeatureInterface {

  /**
   * Feature constructor.
   *
   * @param string $name
   *   The feature name.
   * @param string $label
   *   The feature label.
   * @param string $description
   *   (Optional) The description.
   */
  public function __construct(
    protected string $name,
    protected string $label,
    protected string $description = '',
  ) {}

  /**
   * {@inheritdoc}
   */
  public function name(): string {
    return $this->name;
  }

  /**
   * {@inheritdoc}
   */
  public function label(): string {
    return $this->label;
  }

  /**
   * {@inheritdoc}
   */
  public function description(): string {
    return $this->description;
  }

  /**
   * {@inheritdoc}
   */
  public function toArray(): array {
    return [
      'name' => $this->name,
      'label' => $this->label,
      'description' => $this->description,
    ];
  }

  /**
   * {@inheritdoc}
   */
  public static function fromArray(array $data): static {
    return new Feature($data['name'], $data['label'], $data['description'] ?? '');
  }

}
