<?php

namespace Drupal\feature_toggle;

/**
 * The feature wrapper interface.
 */
interface FeatureInterface {

  /**
   * Returns the feature name.
   *
   * @return string
   *   The feature name.
   */
  public function name(): string;

  /**
   * Returns the feature label.
   *
   * @return string
   *   The feature label.
   */
  public function label(): string;

  /**
   * Returns the feature description.
   *
   * @return string
   *   The feature description.
   */
  public function description(): string;

  /**
   * Converts the feature into an array.
   *
   * @return array
   *   The array version of the feature.
   */
  public function toArray(): array;

  /**
   * Creates a feature from a keyed array.
   *
   * @param array $data
   *   The array data.
   *
   * @return static
   *   The generated feature.
   */
  public static function fromArray(array $data): static;

}
