<?php

namespace Drupal\feature_toggle;

/**
 * Defines the FeatureManager service behavior.
 */
interface FeatureManagerInterface {

  /**
   * Check whether a feature exists or not.
   *
   * @param string $name
   *   The feature name.
   *
   * @return bool
   *   TRUE if the feature exists. FALSE otherwise.
   */
  public function featureExists(string $name): bool;

  /**
   * Returns the feature object given the feature name.
   *
   * @param string $name
   *   The feature name.
   *
   * @return \Drupal\feature_toggle\FeatureInterface|null
   *   The feature object.
   */
  public function getFeature(string $name): ?Feature;

  /**
   * Returns the list of features.
   *
   * @return \Drupal\feature_toggle\FeatureInterface[]
   *   The feature object array.
   */
  public function getFeatures(): array;

  /**
   * Adds a new feature to the system.
   *
   * @param \Drupal\feature_toggle\FeatureInterface $feature
   *   The feature object.
   */
  public function addFeature(FeatureInterface $feature): void;

  /**
   * Updates a feature from the system.
   *
   * @param \Drupal\feature_toggle\FeatureInterface $feature
   *   The feature name.
   */
  public function updateFeature(FeatureInterface $feature): void;

  /**
   * Deletes a feature from the system.
   *
   * @param string $name
   *   The feature name.
   */
  public function deleteFeature(string $name): void;

}
