<?php

declare(strict_types=1);

namespace Drupal\Tests\feature_toggle\Kernel;

use Drupal\Core\Render\RenderContext;
use Drupal\feature_toggle\Feature;
use Drupal\feature_toggle\FeatureStatusInterface;
use Drupal\KernelTests\KernelTestBase;

/**
 * Provides tests for the Twig extension related to feature toggles.
 *
 * @group feature_toggle
 */
class TwigExtensionTest extends KernelTestBase {

  /**
   * {@inheritdoc}
   */
  protected static $modules = [
    'feature_toggle',
  ];

  /**
   * Tests the custom Twig function with various feature toggle statuses.
   */
  public function testTwigFunction(): void {
    /** @var \Drupal\feature_toggle\FeatureStatusInterface $feature_status */
    $feature_status = \Drupal::service(FeatureStatusInterface::class);
    $feature_status->setStatus(new Feature('feature_enabled', 'Enabled'), TRUE);
    $feature_status->setStatus(new Feature('feature_disabled', 'Disabled'), FALSE);
    $this->assertSame('passed', $this->renderFeatureWithTwig('feature_enabled'));
    $this->assertSame('rejected', $this->renderFeatureWithTwig('feature_disabled'));
    $this->assertSame('rejected', $this->renderFeatureWithTwig('feature_missing'));
  }

  /**
   * Renders a feature using twig to test the custom function.
   *
   * @return \Drupal\Component\Render\MarkupInterface
   *   The rendered HTML.
   */
  protected function renderFeatureWithTwig(string $variable): string {
    /** @var \Drupal\Core\Render\RendererInterface $renderer */
    $renderer = \Drupal::service('renderer');
    $context = new RenderContext();
    return (string) $renderer->executeInRenderContext($context, function () use ($renderer, $variable) {
      $elements = [
        '#type' => 'inline_template',
        '#template' => '{%- if feature_toggle_status(variable) -%}passed{%- else -%}rejected{%- endif -%}',
        '#context' => ['variable' => $variable],
      ];
      return $renderer->render($elements);
    });
  }

}
