<?php

declare(strict_types=1);

namespace Drupal\Tests\feature_toggle\Unit;

use Drupal\Core\Access\AccessResult;
use Drupal\feature_toggle\Access\FeatureToggleAccessCheck;
use Drupal\feature_toggle\FeatureStatusInterface;
use Drupal\Tests\UnitTestCase;
use Symfony\Component\Routing\Route;

/**
 * Unit test of feature_toggle access checking system.
 *
 * @coversDefaultClass \Drupal\feature_toggle\Access\FeatureToggleAccessCheck
 *
 * @group feature_toggle
 */
class FeatureToggleAccessCheckTest extends UnitTestCase {

  /**
   * Tests access.
   *
   * @covers ::access
   */
  public function testAccess(): void {
    $feature_status = $this->prophesize(FeatureStatusInterface::class);
    $call_count = 0;

    $feature_status->getStatus('test_feature')->will(function () use (&$call_count) {
      $call_count++;
      return (bool) ($call_count % 2);
    });
    $feature_status->getStatus('missing_feature')->willReturn(FALSE);
    $feature_status = $feature_status->reveal();
    $access_check = new FeatureToggleAccessCheck($feature_status);

    $enabled_route = new Route('/foo', [], ['_feature_toggle' => 'test_feature.1']);
    $this->assertEquals(AccessResult::allowed()->addCacheTags(['feature_toggle:test_feature']), $access_check->access($enabled_route));
    $this->assertEquals(AccessResult::neutral()->addCacheTags(['feature_toggle:test_feature']), $access_check->access($enabled_route));

    $disabled_route = new Route('/foo', [], ['_feature_toggle' => 'test_feature.0']);
    $this->assertEquals(AccessResult::neutral()->addCacheTags(['feature_toggle:test_feature']), $access_check->access($disabled_route));
    $this->assertEquals(AccessResult::allowed()->addCacheTags(['feature_toggle:test_feature']), $access_check->access($disabled_route));

    $default_route = new Route('/foo', [], ['_feature_toggle' => 'test_feature']);
    $this->assertEquals(AccessResult::allowed()->addCacheTags(['feature_toggle:test_feature']), $access_check->access($default_route));
    $this->assertEquals(AccessResult::neutral()->addCacheTags(['feature_toggle:test_feature']), $access_check->access($default_route));

    $missing_route = new Route('/foo', [], ['_feature_toggle' => 'missing_feature']);
    $this->assertEquals(AccessResult::neutral()->addCacheTags(['feature_toggle:missing_feature']), $access_check->access($missing_route));
    $this->assertEquals(AccessResult::neutral()->addCacheTags(['feature_toggle:missing_feature']), $access_check->access($missing_route));
  }

}
